@@ -28,6 +28,11 @@ def version_msg():
     is_flag=True,
     help=u'Do not prompt for parameters and only use cookiecutter.json ' u'file content',
 )
+@click.option(
+    u'--offline',
+    is_flag=True,
+    help=u'Disable Async Http Project Existence Check, on PyPI and RTD servers',
+)
 @click.option(
     u'-c',
     u'--checkout',
@@ -73,6 +78,7 @@ def version_msg():
 )
 def main(
     no_input,
+    offline: bool,
     checkout,
     replay,
     overwrite,
@@ -91,8 +97,9 @@ def main(
     # TODO Improvement: add logging configuration
     try:
         project: str = generate(
-            checkout,
-            no_input,
+            checkout=checkout,
+            offline=offline,
+            no_input=no_input,
             replay=replay,
             overwrite=overwrite,
             output_dir=output_dir,
